function Y = normalize_labels(X)
%  Y = normalize_labels(X)
%      Convert a cell array of rich chord labels into a 
%      list of integers in a reduced set (1-25)
% 2008-08-11 Dan Ellis dpwe@ee.columbia.edu

% Canonical chord label index
labs = {'C','C#','D','D#','E','F','F#','G','G#','A','A#','B', ...
        'C:min','C#:min','D:min','D#:min','E:min','F:min', ...
        'F#:min','G:min','G#:min','A:min','A#:min','B:min', ...
        'N'};

ul = unique(X);

flats = {'Ab','Bb','Db','Eb','Gb'};
shrps = {'G#','A#','C#','D#','F#'};

Y = zeros(1,length(X));

for i = 1:length(ul)
  u = ul{i};
  % Convert this label
  [r,s] = splitchordlab(u);
  ix = find(strcmp(flats,r));
  if length(ix) > 0
    r = shrps{ix};
  end
  if strncmp(s,'min',3)
    u2 = [r,':min']; 
  else 
    u2 = r; 
  end; 
  % find its index
  un = find(strcmp(labs, u2));
  % write it in
  Y(strcmp(X,u)) = un;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [r,s] = splitchordlab(L)
s = '';
x = min(find(L=='/'));
if length(x)
  L = L(1:x-1);
end
r = L;
x = min(find(L==':'));
if length(x)
  r = L(1:x-1);
  s = L(x+1:end);
end
